@@ -1,4 +1,16 @@
-import getpass, os, time, subprocess, math, pickle, queue, threading, argparse, time, backoff, shutil, gc
+import getpass
+import os
+import json
+import subprocess
+import math
+import pickle
+import queue
+import threading
+import argparse
+import time
+import backoff
+import shutil
+import gc
 import numpy as np
 import pandas as pd
 import pyvo as vo
@@ -42,10 +54,34 @@ class WISEDataDESYCluster(WiseDataByVisit):
         self._io_queue = queue.PriorityQueue()
         self._io_queue_done = queue.Queue()
 
+    def _load_lightcurves(
+            self,
+            service,
+            chunk_number=None,
+            jobID=None,
+            return_filename=False,
+            load_from_bigdata_dir=False
+    ):
+        fn = self._lightcurve_filename(service, chunk_number, jobID)
+
+        if load_from_bigdata_dir:
+            fn = fn.replace(data_dir, bigdata_dir)
+
+        logger.debug(f"loading {fn}")
+        try:
+            with open(fn, "r") as f:
+                lcs = json.load(f)
+            if return_filename:
+                return lcs, fn
+            return lcs
+        except FileNotFoundError:
+            logger.warning(f"No file {fn}")
+
     def get_sample_photometric_data(self, max_nTAPjobs=8, perc=1, tables=None, chunks=None,
                                     cluster_jobs_per_chunk=100, wait=5, remove_chunks=False,
                                     query_type='positional', overwrite=True,
-                                    storage_directory=bigdata_dir):
+                                    storage_directory=bigdata_dir,
+                                    skip_download=False):
         """
         An alternative to `get_photometric_data()` that uses the DESY cluster and is optimised for large datasets.
 
@@ -107,7 +143,7 @@ class WISEDataDESYCluster(WiseDataByVisit):
 
         logger.debug(f"Getting {perc * 100:.2f}% of lightcurve chunks ({len(chunks)}) via {service} "
                      f"in {'magnitude' if mag else ''} {'flux' if flux else ''} "
-                     f"from {tables}")
+                     f"from {tables}\nskipping download: {skip_download}")
 
         input('Correct? [hit enter] ')
 
@@ -145,8 +181,13 @@ class WISEDataDESYCluster(WiseDataByVisit):
         self.start_time = time.time()
         self._total_tasks = len(chunks)
         self._done_tasks = 0
+
         for c in chunks:
-            self._tap_queue.put((tables, c, wait, mag, flux, cluster_time, query_type))
+            if not skip_download:
+                self._tap_queue.put((tables, c, wait, mag, flux, cluster_time, query_type))
+            else:
+                self._cluster_queue.put((cluster_time, c))
+
         status_thread.start()
 
         # --------------------------- wait for completion --------------------------- #
@@ -399,7 +440,7 @@ class WISEDataDESYCluster(WiseDataByVisit):
             ids = list()
         else:
             # Extract the list of job IDs
-            ids = np.array([int(s.split(' ')[2]) for s in st.split('\n')[2:-1]])
+            ids = np.array([int(s.split(' ')[1]) for s in st.split('\n')[2:-1]])
         return ids
 
     def _ntasks_from_qstat_command(self, qstat_command, job_id):
